# Schema containing a single-element allOf

- [1. Property `Schema containing a single-element allOf > allOf > my_reference`](#allOf_i0)

**Title:** Schema containing a single-element allOf

| Type                      | `combining`                                                               |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
|                           |                                                                           |

**Description:** Schema containing a single-element allOf

## <a name="allOf_i0"></a>1. Property `Schema containing a single-element allOf > allOf > my_reference`

| Type                      | `string`                                                                  |
| ------------------------- | ------------------------------------------------------------------------- |
| **Additional properties** | [[Any type: allowed]](# "Additional Properties of any type are allowed.") |
| **Defined in**            | #/definitions/my_reference                                                |
|                           |                                                                           |

**Description:** My string definition

----------------------------------------------------------------------------------------------------------------------------
Generated using [json-schema-for-humans](https://github.com/coveooss/json-schema-for-humans) on date